==> okteta_0.26.3.orig.tar.xz: okteta-0.26.3/kasten/controllers/view/structures/datatypes/primitive/floatdatainformation.hpp <==
/*
 *   This file is part of the Okteta Kasten Framework, made within the KDE community.
 *
 *   Copyright 2009, 2010, 2011  Alex Richardson <alex.richardson@gmx.de>
 *
 *   This library is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU Lesser General Public
 *   License as published by the Free Software Foundation; either
 *   version 2.1 of the License, or (at your option) version 3, or any
 *   later version accepted by the membership of KDE e.V. (or its
 *   successor approved by the membership of KDE e.V.), which shall
 *   act as a proxy defined in Section 6 of version 3 of the license.
 *
 *   This library is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *   Lesser General Public License for more details.
 *
 *   You should have received a copy of the GNU Lesser General Public
 *   License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */
#ifndef KASTEN_FLOATDATAINFORMATION_HPP
#define KASTEN_FLOATDATAINFORMATION_HPP

#include "primitivedatainformation.hpp"

class FloatDataInformationMethods
{
public:
    static PrimitiveDataType staticType();
    static QString staticValueString(float value);
    static QScriptValue asScriptValue(float value, QScriptEngine* engine, ScriptHandlerInfo* handler);
    static float fromVariant(const QVariant& value, bool* ok);

    static QWidget* staticCreateEditWidget(QWidget* parent);
    static QVariant staticDataFromWidget(const QWidget* w);
    static void staticSetWidgetData(float value, QWidget* w);
};

inline PrimitiveDataType FloatDataInformationMethods::staticType()
{
    return PrimitiveDataType::Float;
}

inline float FloatDataInformationMethods::fromVariant(const QVariant& value, bool* ok)
{
    Q_CHECK_PTR(ok);
    float result = value.toFloat(ok);
    // result != result if value is NaN so check for that case too
    if (double(result) != value.toDouble() && result == result) {
        *ok = false;
    }
    return result;
}

#endif /* KASTEN_FLOATDATAINFORMATION_HPP */

==> okteta_0.26.25.orig.tar.xz: okteta-0.26.25/kasten/controllers/view/structures/datatypes/primitive/floatdatainformation.hpp <==
/*
    This file is part of the Okteta Kasten Framework, made within the KDE community.

    SPDX-FileCopyrightText: 2009, 2010, 2011 Alex Richardson <alex.richardson@gmx.de>

    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
*/

#ifndef KASTEN_FLOATDATAINFORMATION_HPP
#define KASTEN_FLOATDATAINFORMATION_HPP

#include "primitivedatainformation.hpp"

class FloatDataInformationMethods
{
public:
    static PrimitiveDataType staticType();
    static QString staticValueString(float value);
    static QScriptValue asScriptValue(float value, QScriptEngine* engine, ScriptHandlerInfo* handler);
    static float fromVariant(const QVariant& value, bool* ok);
    static QVariant staticToQVariant(float value);

    static QWidget* staticCreateEditWidget(QWidget* parent);
    static QVariant staticDataFromWidget(const QWidget* w);
    static void staticSetWidgetData(float value, QWidget* w);
};

inline PrimitiveDataType FloatDataInformationMethods::staticType()
{
    return PrimitiveDataType::Float;
}

inline QVariant FloatDataInformationMethods::staticToQVariant(float value)
{
    return QVariant(value);
}

inline float FloatDataInformationMethods::fromVariant(const QVariant& value, bool* ok)
{
    float result = value.toFloat(ok);
    // result != result if value is NaN so check for that case too
    if (double(result) != value.toDouble() && result == result) {
        *ok = false;
    }
    return result;
}

#endif /* KASTEN_FLOATDATAINFORMATION_HPP */
